@@ -1,4 +1,4 @@
-//$Id: Table.java 11322 2007-03-20 12:06:37Z steve.ebersole@jboss.com $
+//$Id: Table.java 14034 2007-09-29 17:18:42Z d.plentz $
 package org.hibernate.mapping;
 
 import java.io.Serializable;
@@ -254,13 +254,16 @@ public class Table implements RelationalModel, Serializable {
 				throw new HibernateException( "Missing column: " + col.getName() + " in " + Table.qualify( tableInfo.getCatalog(), tableInfo.getSchema(), tableInfo.getName()));
 			}
 			else {
-				final boolean typesMatch = col.getSqlType( dialect, mapping )
+				final boolean typesMatch = col.getSqlType( dialect, mapping ).toLowerCase()
 						.startsWith( columnInfo.getTypeName().toLowerCase() )
 						|| columnInfo.getTypeCode() == col.getSqlTypeCode( mapping );
 				if ( !typesMatch ) {
 					throw new HibernateException(
-							"Wrong column type: " + col.getName() +
-									", expected: " + col.getSqlType( dialect, mapping )
+							"Wrong column type in " +
+							Table.qualify( tableInfo.getCatalog(), tableInfo.getSchema(), tableInfo.getName()) +
+							" for column " + col.getName() +
+							". Found: " + columnInfo.getTypeName().toLowerCase() +
+							", expected: " + col.getSqlType( dialect, mapping )
 					);
 				}
 			}
