@@ -1,4 +1,4 @@
-// $Id: TypeFactory.java 11495 2007-05-09 03:52:56Z steve.ebersole@jboss.com $
+// $Id: TypeFactory.java 12936 2007-08-14 19:45:56Z gbadner $
 package org.hibernate.type;
 
 import java.io.Serializable;
@@ -553,7 +553,7 @@ public final class TypeFactory {
 				AbstractComponentType componentType = ( AbstractComponentType ) types[i];
 				Type[] subtypes = componentType.getSubtypes();
 				Object[] origComponentValues = original[i] == null ? new Object[subtypes.length] : componentType.getPropertyValues( original[i], session );
-				Object[] targetComponentValues = componentType.getPropertyValues( target[i], session );
+				Object[] targetComponentValues = target[i] == null ? new Object[subtypes.length] : componentType.getPropertyValues( target[i], session );
 				replaceAssociations( origComponentValues, targetComponentValues, subtypes, session, null, copyCache, foreignKeyDirection );
 				copied[i] = target[i];
 			}
