@@ -1,4 +1,4 @@
-//$Id: AllTests.java 11645 2007-06-06 21:33:31Z steve.ebersole@jboss.com $
+//$Id: AllTests.java 14290 2008-01-25 02:34:41Z gbadner $
 package org.hibernate.test;
 
 import java.lang.reflect.Constructor;
@@ -20,7 +20,8 @@ import org.hibernate.test.bidi.AuctionTest;
 import org.hibernate.test.bidi.AuctionTest2;
 import org.hibernate.test.bytecode.BytecodeSuite;
 import org.hibernate.test.cache.CacheSuite;
-import org.hibernate.test.cascade.RefreshTest;
+import org.hibernate.test.cascade.CascadeSuite;
+import org.hibernate.test.cfg.ListenerTest;
 import org.hibernate.test.cid.CompositeIdTest;
 import org.hibernate.test.collection.CollectionSuite;
 import org.hibernate.test.component.ComponentSuite;
@@ -37,6 +38,7 @@ import org.hibernate.test.dynamicentity.interceptor.InterceptorDynamicEntityTest
 import org.hibernate.test.dynamicentity.tuplizer.TuplizerDynamicEntityTest;
 import org.hibernate.test.ecid.EmbeddedCompositeIdTest;
 import org.hibernate.test.entitymode.EntityModeSuite;
+import org.hibernate.test.event.collection.CollectionEventSuite;
 import org.hibernate.test.exception.SQLExceptionConversionTest;
 import org.hibernate.test.extralazy.ExtraLazyTest;
 import org.hibernate.test.filter.DynamicFilterTest;
@@ -56,7 +58,7 @@ import org.hibernate.test.instrument.runtime.JavassistInstrumentationTest;
 import org.hibernate.test.interceptor.InterceptorTest;
 import org.hibernate.test.interfaceproxy.InterfaceProxyTest;
 import org.hibernate.test.iterate.IterateTest;
-import org.hibernate.test.join.JoinTest;
+import org.hibernate.test.join.JoinSuite;
 import org.hibernate.test.joinedsubclass.JoinedSubclassTest;
 import org.hibernate.test.joinfetch.JoinFetchTest;
 import org.hibernate.test.jpa.JPAComplianceSuite;
@@ -222,7 +224,7 @@ public class AllTests {
 			suite.addTest( DynamicFilterTest.suite() );
 			suite.addTest( InterfaceProxyTest.suite() );
 			suite.addTest( OrphanSuite.suite() );
-			suite.addTest( JoinTest.suite() );
+			suite.addTest( JoinSuite.suite() );
 			suite.addTest( JoinedSubclassTest.suite() );
 			suite.addTest( org.hibernate.test.unionsubclass2.UnionSubclassTest.suite() );
 			suite.addTest( MixedTest.suite() );
@@ -258,7 +260,9 @@ public class AllTests {
 			suite.addTest( SortTest.suite() );
 			suite.addTest( WhereTest.suite() );
 			suite.addTest( IterateTest.suite() );
-			suite.addTest( RefreshTest.suite() );
+			suite.addTest( CascadeSuite.suite() );
+			suite.addTest( ListenerTest.suite() );
+			suite.addTest( CollectionEventSuite.suite() );
 			suite.addTest( ExtraLazyTest.suite() );
 			suite.addTest( StatsTest.suite() );
 			suite.addTest( SessionStatsTest.suite() );
