@@ -1,4 +1,4 @@
-// $Id: DynamicFilterTest.java 10976 2006-12-12 23:22:26Z steve.ebersole@jboss.com $
+// $Id: DynamicFilterTest.java 14053 2007-10-03 04:55:03Z steve.ebersole@jboss.com $
 package org.hibernate.test.filter;
 
 import java.util.ArrayList;
@@ -67,6 +67,13 @@ public class DynamicFilterTest extends FunctionalTestCase {
 		return new FunctionalTestClassTestSuite( DynamicFilterTest.class );
 	}
 
+	public void testSqlSyntaxOfFiltersWithUnions() {
+		Session session = openSession();
+		session.enableFilter( "unioned" );
+		session.createQuery( "from Category" ).list();
+		session.close();
+	}
+
 	public void testSecondLevelCachedCollectionsFiltering() {
 		TestData testData = new TestData();
 		testData.prepare();
