@@ -1,4 +1,4 @@
-// $Id: BulkManipulationTest.java 11656 2007-06-08 01:05:59Z steve.ebersole@jboss.com $
+// $Id: BulkManipulationTest.java 14201 2007-11-16 20:26:30Z steve.ebersole@jboss.com $
 package org.hibernate.test.hql;
 
 import java.util.ArrayList;
@@ -451,6 +451,17 @@ public class BulkManipulationTest extends FunctionalTestCase {
 		s.close();
 	}
 
+	public void testInsertWithSelectListUsingJoins() {
+		// this is just checking parsing and syntax...
+		Session s = openSession();
+		s.beginTransaction();
+		s.createQuery( "insert into Animal (description, bodyWeight) select h.description, h.bodyWeight from Human h where h.mother.mother is not null" ).executeUpdate();
+		s.createQuery( "delete from Animal" ).executeUpdate();
+		s.getTransaction().commit();
+		s.close();
+	}
+
+
 	// UPDATES ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 	public void testIncorrectSyntax() {
