@@ -1,8 +1,9 @@
-//$Id: MasterDetailTest.java 10980 2006-12-13 00:13:43Z steve.ebersole@jboss.com $
+//$Id: MasterDetailTest.java 13932 2007-08-17 18:45:35Z steve.ebersole@jboss.com $
 package org.hibernate.test.legacy;
 
 import java.io.Serializable;
 import java.sql.Connection;
+import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashSet;
@@ -835,6 +836,10 @@ public class MasterDetailTest extends LegacyTestCase {
 	}
 
 	public void testCachedCollectionRefresh() throws Exception {
+		if ( isSerializableIsolationEnforced() ) {
+			reportSkip( "SERIALIZABLE isolation", "cached collection refreshing" );
+			return;
+		}
 		Session s = openSession();
 		Category c = new Category();
 		List list = new ArrayList();
@@ -853,7 +858,9 @@ public class MasterDetailTest extends LegacyTestCase {
 		s.close();
 		
 		s = openSession();
-		if ( (getDialect() instanceof MySQLDialect) ) s.connection().setTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
+		if ( (getDialect() instanceof MySQLDialect) ) {
+			s.connection().setTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
+		}
 		c = (Category) s.load(Category.class, id);
 		c.getSubcategories().size(); //force load
 
