@@ -12,13 +12,15 @@ public class User implements java.io.Serializable {
 	private String userName;
 	private String password;
 	private String email;
-	private String firstName;
-	private Character initial;
-	private String lastName;
 
 	public User() {
 	}
 
+	public User(String userName, String password) {
+		this.userName = userName;
+		this.password = password;
+	}
+
 	public Integer getMyUserId() {
 		return this.myUserId;
 	}
@@ -51,30 +53,6 @@ public class User implements java.io.Serializable {
 		this.email = email;
 	}
 
-	public String getFirstName() {
-		return this.firstName;
-	}
-
-	public void setFirstName(String firstName) {
-		this.firstName = firstName;
-	}
-
-	public Character getInitial() {
-		return this.initial;
-	}
-
-	public void setInitial(Character initial) {
-		this.initial = initial;
-	}
-
-	public String getLastName() {
-		return this.lastName;
-	}
-
-	public void setLastName(String lastName) {
-		this.lastName = lastName;
-	}
-
 	public Integer getVersion() {
 		return this.version;
 	}
